aboutsummaryrefslogtreecommitdiff
path: root/crosperf
diff options
context:
space:
mode:
authorCaroline Tice <cmtice@google.com>2016-07-20 12:52:59 -0700
committerchrome-bot <chrome-bot@chromium.org>2016-07-25 11:00:38 -0700
commita8af9a7a2462b00e72deff99327bdb452a715277 (patch)
tree92573f258457cc6a737c10df0dd250265b9efb8d /crosperf
parent19b6f5fc11dcf97144e9723c8f78534cce27423a (diff)
downloadtoolchain-utils-a8af9a7a2462b00e72deff99327bdb452a715277.tar.gz
[toolchain-utils] Finish switching utils/ to cros_utils/.
This CL finishes switching the subdirectory from 'utils' to 'cros_utils'. It changes all the remaining import statements to use 'cros_utils'; it removes the 'cros_utils' symlink, and it renames the 'utils' subdirectory to 'cros_utils'. BUG=chromium:568195 TEST=ran crosperf & binary search tool unittests. Change-Id: I7427f8bfb2ddac3a4b6108e46782039059684382 Reviewed-on: https://chrome-internal-review.googlesource.com/270396 Commit-Ready: Caroline Tice <cmtice@google.com> Tested-by: Caroline Tice <cmtice@google.com> Reviewed-by: Cassidy Burden <cburden@google.com> Reviewed-by: Luis Lozano <llozano@chromium.org>
Diffstat (limited to 'crosperf')
-rwxr-xr-xcrosperf/crosperf.py6
-rw-r--r--crosperf/download_images.py2
2 files changed, 4 insertions, 4 deletions
diff --git a/crosperf/download_images.py b/crosperf/download_images.py
index 7079d074..1b971892 100644
--- a/crosperf/download_images.py
+++ b/crosperf/download_images.py
@@ -7,7 +7,7 @@ import os
import test_flag
-from utils import command_executer
+from cros_utils import command_executer
class MissingImage(Exception):
diff --git a/crosperf/crosperf.py b/crosperf/crosperf.py
index e874277b..4c13c02b 100755
--- a/crosperf/crosperf.py
+++ b/crosperf/crosperf.py
@@ -16,10 +16,10 @@ from experiment_factory import ExperimentFactory
from experiment_file import ExperimentFile
from settings_factory import GlobalSettings
# This import causes pylint to warn about "No name 'logger' in module 'utils'".
# I do not understand why. The import works fine in python.
# pylint: disable=no-name-in-module
-from utils import logger
+from cros_utils import logger
import test_flag
@@ -16,10 +16,10 @@ from experiment_factory import ExperimentFactory
from experiment_file import ExperimentFile
from settings_factory import GlobalSettings
-# This import causes pylint to warn about "No name 'logger' in module 'utils'".
-# I do not understand why. The import works fine in python.
+# This import causes pylint to warn about "No name 'logger' in module
+# 'cros_utils'". I do not understand why. The import works fine in python.
# pylint: disable=no-name-in-module